from django.contrib import admin
from stager.staging.models import *
from forms import *
from django.contrib.admin.models import LogEntry

# User Preferences
class UserPreferenceAdmin(admin.ModelAdmin):
    fields = ('user', 'default_display',)


# CLIENT PAGE
class ProjectInline(admin.TabularInline):
    model = Project
    fields = ('name', 'path', 'active')
    template = 'admin/staging/edit_inline/tabular.html'
    modeltype = 'project'


class ClientAdmin(admin.ModelAdmin):
    fields = ('name', 'path', 'logo', 'active', 'user', 'contact')
    prepopulated_fields = {"path": ("name",)}
    inlines = [ProjectInline,]
    form = ClientLogoSizeAdminForm
    ordering = ['name']
    class Media:
        js = ('js/jquery.1.3.1.min.js', 'js/client.js',)


# PROJECT PAGE
    
class SectionInline(admin.TabularInline):
    model = Section
    template = 'admin/staging/edit_inline/tabular.html'
    modeltype = 'section'
    fields = ('name', 'ordering')
    fk_name = "project"
    sortable_field_name = "ordering"
    extra = 0

class ResourcesInline(admin.TabularInline):
    model = Link
    template = 'admin/staging/edit_inline/tabular.html'
    modeltype = 'link'
    verbose_name = "Project Resource"
    verbose_name_plural = "Project Resources"
    fields = ('name', 'remote_link', 'file_link', 'ordering', 'active')   
    form = LinkSizeAdminForm

class ProjectAdmin(admin.ModelAdmin):
    save_on_top = True
    fields = ('client', 'name', 'path', 'active')
    prepopulated_fields = {"path": ("name",)}
    list_filter = ('client', )
    ordering = ['-client', 'name']
    inlines = [SectionInline, ResourcesInline]

    class Media:
        js = ('js/jquery.1.3.1.min.js', 'js/admin_links.js',)


#SECTION PAGE    
class LinkInline(admin.TabularInline):
    model = Link
    template = 'admin/staging/edit_inline/tabular.html'
    modeltype = 'link'
    fields = ('name', 'remote_link', 'file_link', 'ordering', 'active')
    form = LinkSizeAdminForm
    sortable_field_name = "ordering"
    extra = 0

class CompSlideInline(admin.TabularInline):
    template = 'admin/staging/edit_inline/_comp_slide_drag_upload.html'
    model = CompSlide
    form = SlideSizeAdminForm
    sortable_field_name = "ordering"
    extra = 0
    modeltype = 'compslide'

class SectionAdmin(admin.ModelAdmin):
    fields = ('project', 'name', 'description', 'active')
    inlines = [CompSlideInline, LinkInline]


    class Media:
        js = ('js/jquery.1.3.1.min.js', 'js/admin_links.js',)


# CONTACT PAGE
class ContactAdmin(admin.ModelAdmin):
    filter_horizontal = ('projects', )

class CompSlideAdmin(admin.ModelAdmin):
    model = CompSlide
    list_display = ('name', 'linked','image')
    form = SlideSizeAdminForm


class LinkAdmin(admin.ModelAdmin):
    form = LinkSizeAdminForm
    list_display = ('linked', 'remote_link','file_link', 'active', 'ordering')

#class CategoryAdmin(admin.ModelAdmin):
#    list_display = ('name', 'project')

class LogEntryAdmin(admin.ModelAdmin):
    model = LogEntry
    list_display = ('object_repr','content_type','user','change_message','action_time')

try:
    admin.site.register(UserPreference, UserPreferenceAdmin)
    admin.site.register(Section, SectionAdmin)
    admin.site.register(Project, ProjectAdmin)
    admin.site.register(Client, ClientAdmin)
    admin.site.register(Contact, ContactAdmin)
    admin.site.register(Link, LinkAdmin)
    admin.site.register(CompSlide, CompSlideAdmin)
    admin.site.register(LogEntry, LogEntryAdmin)    
except:
    pass
