# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Client'
        db.create_table('staging_client', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=100)),
            ('active', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('path', self.gf('django.db.models.fields.CharField')(unique=True, max_length=100)),
            ('logo', self.gf('django.db.models.fields.files.ImageField')(max_length=100, null=True, blank=True)),
            ('user', self.gf('django.db.models.fields.related.ForeignKey')(related_name='users', to=orm['auth.User'])),
            ('contact', self.gf('django.db.models.fields.related.ForeignKey')(blank=True, related_name='clients', null=True, to=orm['staging.Contact'])),
        ))
        db.send_create_signal('staging', ['Client'])

        # Adding model 'Container'
        db.create_table('staging_container', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=100)),
            ('description', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('active', self.gf('django.db.models.fields.BooleanField')(default=True)),
        ))
        db.send_create_signal('staging', ['Container'])

        # Adding model 'Project'
        db.create_table('staging_project', (
            ('container_ptr', self.gf('django.db.models.fields.related.OneToOneField')(to=orm['staging.Container'], unique=True, primary_key=True)),
            ('client', self.gf('django.db.models.fields.related.ForeignKey')(related_name='projects', to=orm['staging.Client'])),
            ('path', self.gf('django.db.models.fields.CharField')(max_length=100)),
        ))
        db.send_create_signal('staging', ['Project'])

        # Adding model 'Contact'
        db.create_table('staging_contact', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('first_name', self.gf('django.db.models.fields.CharField')(max_length=100, blank=True)),
            ('last_name', self.gf('django.db.models.fields.CharField')(max_length=100, blank=True)),
            ('telephone', self.gf('django.db.models.fields.CharField')(max_length=100, blank=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=100, blank=True)),
            ('email', self.gf('django.db.models.fields.EmailField')(max_length=75)),
            ('active', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('ai_staff', self.gf('django.db.models.fields.BooleanField')(default=False)),
            ('ordering', self.gf('django.db.models.fields.IntegerField')(default=0)),
        ))
        db.send_create_signal('staging', ['Contact'])

        # Adding M2M table for field projects on 'Contact'
        db.create_table('staging_contact_projects', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('contact', models.ForeignKey(orm['staging.contact'], null=False)),
            ('project', models.ForeignKey(orm['staging.project'], null=False))
        ))
        db.create_unique('staging_contact_projects', ['contact_id', 'project_id'])

        # Adding model 'Category'
        db.create_table('staging_category', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=100)),
            ('project', self.gf('django.db.models.fields.related.ForeignKey')(related_name='categories', to=orm['staging.Project'])),
            ('ordering', self.gf('django.db.models.fields.IntegerField')(default=0)),
            ('active', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('default', self.gf('django.db.models.fields.BooleanField')(default=False)),
        ))
        db.send_create_signal('staging', ['Category'])

        # Adding model 'Section'
        db.create_table('staging_section', (
            ('container_ptr', self.gf('django.db.models.fields.related.OneToOneField')(to=orm['staging.Container'], unique=True, primary_key=True)),
            ('project', self.gf('django.db.models.fields.related.ForeignKey')(related_name='sections', to=orm['staging.Project'])),
            ('date', self.gf('django.db.models.fields.DateField')()),
            ('category', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['staging.Category'])),
        ))
        db.send_create_signal('staging', ['Section'])

        # Adding model 'Subsection'
        db.create_table('staging_subsection', (
            ('container_ptr', self.gf('django.db.models.fields.related.OneToOneField')(to=orm['staging.Container'], unique=True, primary_key=True)),
            ('section', self.gf('django.db.models.fields.related.ForeignKey')(related_name='subsections', to=orm['staging.Container'])),
        ))
        db.send_create_signal('staging', ['Subsection'])

        # Adding model 'Link'
        db.create_table('staging_link', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('remote_link', self.gf('django.db.models.fields.URLField')(max_length=200, null=True, blank=True)),
            ('file_link', self.gf('django.db.models.fields.files.FileField')(max_length=100, null=True, blank=True)),
            ('linked', self.gf('django.db.models.fields.related.ForeignKey')(related_name='links', to=orm['staging.Container'])),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=100, blank=True)),
            ('active', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('ordering', self.gf('django.db.models.fields.IntegerField')(default=0)),
        ))
        db.send_create_signal('staging', ['Link'])

        # Adding model 'Comp'
        db.create_table('staging_comp', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=128)),
            ('background', self.gf('django.db.models.fields.files.ImageField')(max_length=100, null=True, blank=True)),
            ('remove_background', self.gf('django.db.models.fields.BooleanField')(default=False)),
            ('background_colorfield', self.gf('stager.staging.models.ColorField')(max_length=10, blank=True)),
            ('ordering', self.gf('django.db.models.fields.IntegerField')(default=0)),
            ('active', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('linked', self.gf('django.db.models.fields.related.ForeignKey')(related_name='comps', to=orm['staging.Container'])),
        ))
        db.send_create_signal('staging', ['Comp'])

        # Adding model 'CompSlide'
        db.create_table('staging_compslide', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=128)),
            ('comp', self.gf('django.db.models.fields.related.ForeignKey')(related_name='slides', to=orm['staging.Comp'])),
            ('image', self.gf('django.db.models.fields.files.ImageField')(max_length=100, null=True, blank=True)),
            ('alignment', self.gf('django.db.models.fields.CharField')(max_length=128, null=True, blank=True)),
            ('backgroundfield', self.gf('django.db.models.fields.files.ImageField')(max_length=100, null=True, blank=True)),
            ('remove_background', self.gf('django.db.models.fields.BooleanField')(default=False)),
            ('background_colorfield', self.gf('stager.staging.models.ColorField')(max_length=10, blank=True)),
            ('active', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('ordering', self.gf('django.db.models.fields.IntegerField')(default=0)),
        ))
        db.send_create_signal('staging', ['CompSlide'])


    def backwards(self, orm):
        # Deleting model 'Client'
        db.delete_table('staging_client')

        # Deleting model 'Container'
        db.delete_table('staging_container')

        # Deleting model 'Project'
        db.delete_table('staging_project')

        # Deleting model 'Contact'
        db.delete_table('staging_contact')

        # Removing M2M table for field projects on 'Contact'
        db.delete_table('staging_contact_projects')

        # Deleting model 'Category'
        db.delete_table('staging_category')

        # Deleting model 'Section'
        db.delete_table('staging_section')

        # Deleting model 'Subsection'
        db.delete_table('staging_subsection')

        # Deleting model 'Link'
        db.delete_table('staging_link')

        # Deleting model 'Comp'
        db.delete_table('staging_comp')

        # Deleting model 'CompSlide'
        db.delete_table('staging_compslide')


    models = {
        'auth.group': {
            'Meta': {'object_name': 'Group'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'ordering': "('content_type__app_label', 'content_type__model', 'codename')", 'unique_together': "(('content_type', 'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'staging.category': {
            'Meta': {'ordering': "['ordering']", 'object_name': 'Category'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'default': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'ordering': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'project': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'categories'", 'to': "orm['staging.Project']"})
        },
        'staging.client': {
            'Meta': {'object_name': 'Client'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'contact': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'clients'", 'null': 'True', 'to': "orm['staging.Contact']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'logo': ('django.db.models.fields.files.ImageField', [], {'max_length': '100', 'null': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'path': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '100'}),
            'user': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'users'", 'to': "orm['auth.User']"})
        },
        'staging.comp': {
            'Meta': {'ordering': "['ordering']", 'object_name': 'Comp'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'background': ('django.db.models.fields.files.ImageField', [], {'max_length': '100', 'null': 'True', 'blank': 'True'}),
            'background_colorfield': ('stager.staging.models.ColorField', [], {'max_length': '10', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'linked': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'comps'", 'to': "orm['staging.Container']"}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'ordering': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'remove_background': ('django.db.models.fields.BooleanField', [], {'default': 'False'})
        },
        'staging.compslide': {
            'Meta': {'ordering': "['ordering']", 'object_name': 'CompSlide'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'alignment': ('django.db.models.fields.CharField', [], {'max_length': '128', 'null': 'True', 'blank': 'True'}),
            'background_colorfield': ('stager.staging.models.ColorField', [], {'max_length': '10', 'blank': 'True'}),
            'backgroundfield': ('django.db.models.fields.files.ImageField', [], {'max_length': '100', 'null': 'True', 'blank': 'True'}),
            'comp': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'slides'", 'to': "orm['staging.Comp']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('django.db.models.fields.files.ImageField', [], {'max_length': '100', 'null': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'ordering': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'remove_background': ('django.db.models.fields.BooleanField', [], {'default': 'False'})
        },
        'staging.contact': {
            'Meta': {'ordering': "['ordering']", 'object_name': 'Contact'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'ai_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '100', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '100', 'blank': 'True'}),
            'ordering': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'projects': ('django.db.models.fields.related.ManyToManyField', [], {'related_name': "'contacts'", 'symmetrical': 'False', 'to': "orm['staging.Project']"}),
            'telephone': ('django.db.models.fields.CharField', [], {'max_length': '100', 'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '100', 'blank': 'True'})
        },
        'staging.container': {
            'Meta': {'object_name': 'Container'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'staging.link': {
            'Meta': {'ordering': "['ordering']", 'object_name': 'Link'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'file_link': ('django.db.models.fields.files.FileField', [], {'max_length': '100', 'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'linked': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'links'", 'to': "orm['staging.Container']"}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100', 'blank': 'True'}),
            'ordering': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'remote_link': ('django.db.models.fields.URLField', [], {'max_length': '200', 'null': 'True', 'blank': 'True'})
        },
        'staging.project': {
            'Meta': {'object_name': 'Project', '_ormbases': ['staging.Container']},
            'client': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'projects'", 'to': "orm['staging.Client']"}),
            'container_ptr': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['staging.Container']", 'unique': 'True', 'primary_key': 'True'}),
            'path': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'staging.section': {
            'Meta': {'ordering': "['date']", 'object_name': 'Section', '_ormbases': ['staging.Container']},
            'category': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['staging.Category']"}),
            'container_ptr': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['staging.Container']", 'unique': 'True', 'primary_key': 'True'}),
            'date': ('django.db.models.fields.DateField', [], {}),
            'project': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'sections'", 'to': "orm['staging.Project']"})
        },
        'staging.subsection': {
            'Meta': {'object_name': 'Subsection', '_ormbases': ['staging.Container']},
            'container_ptr': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['staging.Container']", 'unique': 'True', 'primary_key': 'True'}),
            'section': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'subsections'", 'to': "orm['staging.Container']"})
        }
    }

    complete_apps = ['staging']